pub enum WriteReflog {
Always,
Normal,
Disable,
}Expand description
The way a file store handles the reflog
Variants
Always
Always write the reflog for all references for ref edits, unconditionally.
Normal
Write a ref log for ref edits according to the standard rules.
Disable
Never write a ref log.