pub struct Reference {
pub name: FullName,
pub target: Target,
pub peeled: Option<ObjectId>,
}Expand description
A fully owned backend agnostic reference
Fields
name: FullNameThe path to uniquely identify this ref within its store.
target: TargetThe target of the reference, either a symbolic reference by full name or a possibly intermediate object by its id.
peeled: Option<ObjectId>The fully peeled object to which this reference ultimately points to after following all symbolic refs and all annotated
tags. Only guaranteed to be set after
Reference::peel_to_id() was called or if this reference originated
from a packed ref.
Implementations
Sourceimpl Reference
impl Reference
Sourcepub fn name_without_namespace(
&self,
namespace: &Namespace,
) -> Option<&FullNameRef>
pub fn name_without_namespace( &self, namespace: &Namespace, ) -> Option<&FullNameRef>
Return the full validated name of the reference, with the given namespace stripped if possible.
If the reference name wasn’t prefixed with namespace, None is returned instead.
Sourcepub fn strip_namespace(&mut self, namespace: &Namespace) -> &mut Self
pub fn strip_namespace(&mut self, namespace: &Namespace) -> &mut Self
Strip the given namespace from our name as well as the name, but not the reference we point to.